import os.path
def render_html(filename) -> str:
    if os.path.isdir("templates"):
        try:
            return open(f"./templates/{filename}", "r").read()
        except FileNotFoundError:
            pass 
    else:
        print("Must create a folder named: 'templates' and put the file in it")




from distutils.core import setup
setup(
  name = 'yungestWeb',         
  packages = ['yungestWeb'],   
  version = '0.0.3',      
  license='MIT',        
  description = 'TYPE YOUR DESCRIPTION HERE',   
  author = 'yungestDev',                   
  author_email = 'yungestmonsterhahaha@gmail.com',      
  #url = 'https://github.com/user/reponame',   
  #download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    
  keywords = ['WebFramework', 'Framework'],   
  install_requires=[            
          
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      
    'Intended Audience :: Developers',      
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',  
    'Programming Language :: Python :: 3.10',      

  ],
)


from yungestWeb.app import App 
from yungestWeb.request import Request
from yungestWeb.router import Path
from yungestWeb.response import HttpResponse
from yungestWeb.reader_file import render_html
from wsgiref.simple_server import make_server